@@ -14,7 +14,7 @@ use serde::{Deserialize, Serialize};
 use crate::frame::{self, Frame};
 use crate::nodetree;
 use crate::types::{CallTreeError, CallTreesU64};
-use crate::{nodetree::Node, types::Platform, MAX_STACK_DEPTH};
+use crate::{nodetree::Node, MAX_STACK_DEPTH};
 
 const MAIN_THREAD: &str = "main";
 const ANDROID_PACKAGE_PREFIXES: [&str; 11] = [
@@ -43,6 +43,7 @@ pub struct AndroidThread {
 
 #[derive(Serialize, Deserialize, Debug, Default, Eq, PartialEq, Clone)]
 struct AndroidMethod {
+    #[serde(default, skip_serializing_if = "String::is_empty")]
     class_name: String,
     data: Option<Data>,
     // method_id is not optional, but in our Vroom service,
@@ -54,8 +55,11 @@ struct AndroidMethod {
     id: u64,
     #[serde(skip_serializing_if = "Option::is_none")]
     inline_frames: Option<Vec<AndroidMethod>>,
+    #[serde(default, skip_serializing_if = "String::is_empty")]
     name: String,
+    #[serde(default, skip_serializing_if = "String::is_empty")]
     signature: String,
+    #[serde(default, skip_serializing_if = "String::is_empty")]
     source_file: String,
     #[serde(skip_serializing_if = "Option::is_none")]
     source_line: Option<u32>,
@@ -64,7 +68,7 @@ struct AndroidMethod {
     #[serde(skip_serializing_if = "Option::is_none")]
     in_app: Option<bool>,
     #[serde(skip_serializing_if = "Option::is_none")]
-    platform: Option<Platform>,
+    platform: Option<String>,
 }
 
 impl AndroidMethod {
@@ -136,7 +140,7 @@ impl AndroidMethod {
             } else {
                 Some(self.source_file.to_owned())
             },
-            platform: self.platform,
+            platform: self.platform.clone(),
             ..Default::default()
         }
     }
