@@ -3,13 +3,13 @@ use std::time::Duration;
 
 use chrono::{DateTime, Utc};
 use once_cell::sync::Lazy;
-use pyo3::{pyclass, pymethods};
+use pyo3::{pyclass, pymethods, PyErr};
 use serde::Serialize;
 use uuid::Uuid;
 
 use crate::{
     android, frame,
-    types::{CallTreesU64, DebugMeta, Platform, ProfileInterface},
+    types::{CallTreesU64, DebugMeta, ProfileInterface},
 };
 
 mod detect_frame;
@@ -381,6 +381,25 @@ impl Occurrence {
     pub fn get_sample_count(&self) -> u64 {
         self.sample_count
     }
+
+    /// Serializes the occurrence to a JSON string.
+    ///
+    /// Returns:
+    ///     str
+    ///         A JSON string representation of the occurrence.
+    ///
+    /// Raises:
+    ///     ValueError
+    ///         If the serialization fails due to invalid data.
+    ///
+    /// Example:
+    ///     >>> occurrence = occurrences.occurrences[0]
+    ///     >>> json_str = occurrence.to_json_str()
+    ///     >>> print(json_str)
+    pub fn to_json_str(&self) -> Result<String, PyErr> {
+        serde_json::to_string(self)
+            .map_err(|e| PyErr::new::<pyo3::exceptions::PyValueError, _>(e.to_string()))
+    }
 }
 
 pub struct CategoryMetadata {
@@ -636,7 +655,7 @@ pub fn generate_evidence_data(
     match node_info.category.as_str() {
         FRAME_DROP => {}
         _ => {
-            if profile.get_platform() == Platform::Android {
+            if profile.get_platform().as_str() == "android" {
                 evidence_data.sample_count = Some(node_info.node.sample_count);
             }
         }
@@ -705,8 +724,8 @@ pub fn generate_evidence_display(
                 Duration::from_micros(10),
             );
 
-            let duration_str = match profile.get_platform() {
-                Platform::Android => {
+            let duration_str = match profile.get_platform().as_str() {
+                "android" => {
                     format!("{duration:?} ({profile_percentage:.2}% of the profile)")
                 }
                 _ => {
@@ -759,8 +778,8 @@ pub fn new_occurrence(profile: &dyn ProfileInterface, mut ni: NodeInfo) -> Occur
     let mut platform = profile.get_platform();
 
     // Handle Android platform special case
-    if platform == Platform::Android {
-        platform = Platform::Java;
+    if platform.as_str() == "android" {
+        platform = "java".to_string();
         normalize_android_stack_trace(&mut ni.stack_trace);
         ni.node.name =
             android::strip_package_name_from_full_method_name(&ni.node.name, &ni.node.package);
@@ -784,7 +803,7 @@ pub fn new_occurrence(profile: &dyn ProfileInterface, mut ni: NodeInfo) -> Occur
         event_id: event_id(),
         platform: platform.to_string(),
         project_id: profile.get_project_id(),
-        received: DateTime::from_timestamp_micros((profile.get_received() * 1e6) as i64)
+        received: DateTime::from_timestamp(profile.get_received(), 0)
             .expect("timestamp out of range"),
         release: profile.get_release().map(|s| s.to_string()),
         stacktrace: StackTrace {
