@@ -7,7 +7,7 @@ use crate::{
     nodetree::CallTreeFunction,
     occurrence::{self, Occurrence},
     sample::v1::SampleProfile,
-    types::{CallTreeError, CallTreesU64, ProfileInterface},
+    types::{CallTreeError, CallTreesU64, Metadata, ProfileInterface, Transaction},
     utils::{compress_lz4, decompress_lz4},
 };
 
@@ -138,16 +138,7 @@ impl Profile {
     ///
     /// Returns:
     ///     str
-    ///         The profile's platform. One of the following values:
-    ///             * android
-    ///             * cocoa
-    ///             * java
-    ///             * javascript
-    ///             * php
-    ///             * node
-    ///             * python
-    ///             * rust
-    ///             * none
+    ///         The profile's platform.
     pub fn get_platform(&self) -> String {
         self.profile.get_platform().to_string()
     }
@@ -173,8 +164,8 @@ impl Profile {
     /// Returns the received timestamp.
     ///
     /// Returns:
-    ///     float
-    fn get_received(&self) -> f64 {
+    ///     int
+    fn get_received(&self) -> i64 {
         self.profile.get_received()
     }
 
@@ -380,14 +371,34 @@ impl Profile {
     pub fn set_profile_id(&mut self, profile_id: String) {
         self.profile.set_profile_id(profile_id);
     }
+
+    /// Returns the transaction information associated with the profile.
+    ///
+    /// Returns:
+    ///     Transaction
+    ///         The transaction data including ID, name, trace ID, segment ID,
+    ///         active thread ID, and optional duration in nanoseconds.
+    pub fn get_transaction(&self) -> Transaction {
+        self.profile.get_transaction().into_owned()
+    }
+
+    /// Returns metadata information associated with the profile.
+    ///
+    /// This method extracts comprehensive metadata about the profile including
+    /// device information, SDK details, transaction data, and system specifications.
+    ///
+    /// Returns:
+    ///     Metadata
+    ///         A metadata object containing device characteristics, SDK information,
+    ///         transaction details, and other profile-specific data.
+    pub fn get_metadata(&self) -> Metadata {
+        self.profile.get_metadata()
+    }
 }
 
 #[cfg(test)]
 mod tests {
-    use crate::{
-        android::profile::AndroidProfile, profile::Profile, sample::v1::SampleProfile,
-        types::Platform,
-    };
+    use crate::{android::profile::AndroidProfile, profile::Profile, sample::v1::SampleProfile};
 
     #[test]
     fn test_from_json_vec() {
@@ -401,17 +412,17 @@ mod tests {
             TestStruct {
                 name: "cocoa profile".to_string(),
                 profile_json: include_bytes!("../tests/fixtures/sample/v1/valid_cocoa.json"),
-                want: Platform::Cocoa.to_string(),
+                want: "cocoa".to_string(),
             },
             TestStruct {
                 name: "python profile".to_string(),
                 profile_json: include_bytes!("../tests/fixtures/sample/v1/valid_python.json"),
-                want: Platform::Python.to_string(),
+                want: "python".to_string(),
             },
             TestStruct {
                 name: "android profile".to_string(),
                 profile_json: include_bytes!("../tests/fixtures/android/profile/valid.json"),
-                want: Platform::Android.to_string(),
+                want: "android".to_string(),
             },
         ];
 
@@ -441,19 +452,19 @@ mod tests {
                 name: "cocoa profile".to_string(),
                 platform: "cocoa",
                 profile_json: include_bytes!("../tests/fixtures/sample/v1/valid_cocoa.json"),
-                want: Platform::Cocoa.to_string(),
+                want: "cocoa".to_string(),
             },
             TestStruct {
                 name: "python profile".to_string(),
                 platform: "python",
                 profile_json: include_bytes!("../tests/fixtures/sample/v1/valid_python.json"),
-                want: Platform::Python.to_string(),
+                want: "python".to_string(),
             },
             TestStruct {
                 name: "android profile".to_string(),
                 platform: "android",
                 profile_json: include_bytes!("../tests/fixtures/android/profile/valid.json"),
-                want: Platform::Android.to_string(),
+                want: "android".to_string(),
             },
         ];
 
@@ -498,7 +509,7 @@ mod tests {
             let decompressed_profile =
                 Profile::decompress(compressed_profile_bytes.as_slice()).unwrap();
 
-            let equals = if profile.get_platform() == Platform::Android.to_string() {
+            let equals = if profile.get_platform().as_str() == "android" {
                 let original_sample = profile
                     .profile
                     .as_any()
