@@ -3,7 +3,7 @@ use crate::{
     nodetree::Node,
     sample::SampleError,
     types::{
-        CallTreeError, CallTreesU64, ClientSDK, DebugMeta, Platform, ProfileInterface, Transaction,
+        CallTreeError, CallTreesU64, ClientSDK, DebugMeta, ProfileInterface, Transaction,
         TransactionMetadata,
     },
 };
@@ -105,11 +105,11 @@ pub struct SampleProfile {
 
     pub organization_id: u64,
 
-    pub platform: Platform,
+    pub platform: String,
 
     pub project_id: u64,
 
-    pub received: f64,
+    pub received: i64,
 
     #[serde(skip_serializing_if = "Option::is_none")]
     pub release: Option<String>,
@@ -343,8 +343,8 @@ fn find_common_frames<'a>(
 }
 
 impl ProfileInterface for SampleProfile {
-    fn get_platform(&self) -> Platform {
-        self.platform
+    fn get_platform(&self) -> String {
+        self.platform.clone()
     }
 
     /// Serialize the given data structure as a JSON byte vector.
@@ -372,7 +372,7 @@ impl ProfileInterface for SampleProfile {
         self.project_id
     }
 
-    fn get_received(&self) -> f64 {
+    fn get_received(&self) -> i64 {
         self.received
     }
 
@@ -390,11 +390,11 @@ impl ProfileInterface for SampleProfile {
 
     fn normalize(&mut self) {
         for frame in &mut self.profile.frames {
-            frame.normalize(self.platform);
+            frame.normalize(&self.platform);
         }
-        if self.platform == Platform::Cocoa {
+        if self.platform.as_str() == "cocoa" {
             self.trim_cocoa_stacks();
-        } else if self.platform == Platform::Python {
+        } else if self.platform.as_str() == "python" {
             self.profile.trim_python_stacks();
         }
 
@@ -556,6 +556,30 @@ impl ProfileInterface for SampleProfile {
     fn set_profile_id(&mut self, profile_id: String) {
         self.event_id = profile_id
     }
+
+    fn get_metadata(&self) -> crate::types::Metadata {
+        crate::types::Metadata {
+            android_api_level: None, // Not available in v1 sample profiles
+            architecture: self.device.architecture.clone(),
+            device_classification: self.device.classification.clone(),
+            device_locale: self.device.locale.clone(),
+            device_manufacturer: self.device.manufacturer.clone(),
+            device_model: self.device.model.as_deref().unwrap_or("").to_string(),
+            device_os_build_number: self.os.build_number.clone(),
+            device_os_name: self.os.name.clone(),
+            device_os_version: self.os.version.clone(),
+            id: self.event_id.clone(),
+            project_id: self.project_id.to_string(),
+            sdk_name: self.client_sdk.as_ref().map(|sdk| sdk.name.clone()),
+            sdk_version: self.client_sdk.as_ref().map(|sdk| sdk.version.clone()),
+            timestamp: self.timestamp.timestamp(),
+            trace_duration_ms: self.duration_ns() as f64 / 1_000_000.0,
+            transaction_id: self.transaction.id.clone(),
+            transaction_name: self.transaction.name.clone(),
+            version_code: None, // Not available in v1 sample profiles
+            version_name: self.release.clone(),
+        }
+    }
 }
 
 #[cfg(test)]
@@ -568,7 +592,7 @@ mod tests {
     use crate::{
         frame::{self, Data, Frame},
         sample::v1::{Profile, Sample, SampleProfile},
-        types::{CallTreesU64, Platform, ProfileInterface, Transaction},
+        types::{CallTreesU64, ProfileInterface, Transaction},
     };
 
     #[test]
@@ -608,7 +632,7 @@ mod tests {
                                 }),
                                 function: Some("function1".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -618,7 +642,7 @@ mod tests {
                                 }),
                                 function: Some("function2".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -628,7 +652,7 @@ mod tests {
                                 }),
                                 function: Some("main".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -636,7 +660,7 @@ mod tests {
                                     symbolicator_status: Some("missing".to_string()),
                                     ..Default::default()
                                 }),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                         ], // end frames definition
@@ -655,7 +679,7 @@ mod tests {
                                 }),
                                 function: Some("function1".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -665,7 +689,7 @@ mod tests {
                                 }),
                                 function: Some("function2".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -675,7 +699,7 @@ mod tests {
                                 }),
                                 function: Some("main".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -683,7 +707,7 @@ mod tests {
                                     symbolicator_status: Some("missing".to_string()),
                                     ..Default::default()
                                 }),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                         ], // end frames definition
@@ -705,7 +729,7 @@ mod tests {
                                 }),
                                 function: Some("function1".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -715,7 +739,7 @@ mod tests {
                                 }),
                                 function: Some("function2".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -725,7 +749,7 @@ mod tests {
                                 }),
                                 function: Some("main".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -733,7 +757,7 @@ mod tests {
                                     symbolicator_status: Some("missing".to_string()),
                                     ..Default::default()
                                 }),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -743,7 +767,7 @@ mod tests {
                                 }),
                                 function: Some("start_sim".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                         ], // end frames definition
@@ -762,7 +786,7 @@ mod tests {
                                 }),
                                 function: Some("function1".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -772,7 +796,7 @@ mod tests {
                                 }),
                                 function: Some("function2".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -782,7 +806,7 @@ mod tests {
                                 }),
                                 function: Some("main".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -790,7 +814,7 @@ mod tests {
                                     symbolicator_status: Some("missing".to_string()),
                                     ..Default::default()
                                 }),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -800,7 +824,7 @@ mod tests {
                                 }),
                                 function: Some("start_sim".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                         ], // end frames definition
@@ -822,7 +846,7 @@ mod tests {
                                 }),
                                 function: Some("function1".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -832,7 +856,7 @@ mod tests {
                                 }),
                                 function: Some("function2".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -842,7 +866,7 @@ mod tests {
                                 }),
                                 function: Some("unsymbolicated_main".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -850,7 +874,7 @@ mod tests {
                                     symbolicator_status: Some("missing".to_string()),
                                     ..Default::default()
                                 }),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -860,7 +884,7 @@ mod tests {
                                 }),
                                 function: Some("start_sim".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                         ], // end frames definition
@@ -879,7 +903,7 @@ mod tests {
                                 }),
                                 function: Some("function1".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -889,7 +913,7 @@ mod tests {
                                 }),
                                 function: Some("function2".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -899,7 +923,7 @@ mod tests {
                                 }),
                                 function: Some("unsymbolicated_main".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -907,7 +931,7 @@ mod tests {
                                     symbolicator_status: Some("missing".to_string()),
                                     ..Default::default()
                                 }),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -917,7 +941,7 @@ mod tests {
                                 }),
                                 function: Some("start_sim".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                         ], // end frames definition
@@ -939,7 +963,7 @@ mod tests {
                                 }),
                                 function: Some("function1".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -949,7 +973,7 @@ mod tests {
                                 }),
                                 function: Some("function2".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -959,7 +983,7 @@ mod tests {
                                 }),
                                 function: Some("main".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -967,7 +991,7 @@ mod tests {
                                     symbolicator_status: Some("missing".to_string()),
                                     ..Default::default()
                                 }),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -977,7 +1001,7 @@ mod tests {
                                 }),
                                 function: Some("start_sim".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                         ], // end frames definition
@@ -1002,7 +1026,7 @@ mod tests {
                                 }),
                                 function: Some("function1".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -1012,7 +1036,7 @@ mod tests {
                                 }),
                                 function: Some("function2".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -1022,7 +1046,7 @@ mod tests {
                                 }),
                                 function: Some("main".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -1030,7 +1054,7 @@ mod tests {
                                     symbolicator_status: Some("missing".to_string()),
                                     ..Default::default()
                                 }),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                             frame::Frame {
@@ -1040,7 +1064,7 @@ mod tests {
                                 }),
                                 function: Some("start_sim".to_string()),
                                 in_app: Some(true),
-                                platform: Some(Platform::Cocoa),
+                                platform: Some("cocoa".to_string()),
                                 ..Default::default()
                             },
                         ], // end frames definition
@@ -1088,7 +1112,7 @@ mod tests {
                             line: Some(11),
                             function: Some("<module>".to_string()),
                             path: Some("/usr/src/app/<string>".to_string()),
-                            platform: Some(Platform::Python),
+                            platform: Some("python".to_string()),
                             ..Default::default()
                         },
                         Frame {
@@ -1098,7 +1122,7 @@ mod tests {
                             line: Some(98),
                             function: Some("foobar".to_string()),
                             path: Some("/usr/src/app/util.py".to_string()),
-                            platform: Some(Platform::Python),
+                            platform: Some("python".to_string()),
                             ..Default::default()
                         },
                     ],
@@ -1114,7 +1138,7 @@ mod tests {
                             line: Some(11),
                             function: Some("<module>".to_string()),
                             path: Some("/usr/src/app/<string>".to_string()),
-                            platform: Some(Platform::Python),
+                            platform: Some("python".to_string()),
                             ..Default::default()
                         },
                         Frame {
@@ -1124,7 +1148,7 @@ mod tests {
                             line: Some(98),
                             function: Some("foobar".to_string()),
                             path: Some("/usr/src/app/util.py".to_string()),
-                            platform: Some(Platform::Python),
+                            platform: Some("python".to_string()),
                             ..Default::default()
                         },
                     ],
